\name{alligator.dat}
\alias{alligator.dat}
\title{Data frame of alligator food choice by lake, gender and size.}
\description{
  A 5x4x2x2 table of alligators food choice, lake, gender and size
  stored in a data frame.
}
\usage{data(alligator.dat)
}
\format{\code{allgiator.dat} is a data frame
}
\references{Agresti (1990). \emph{Categorical Data
  Analysis}. Wiley-Interscience. Page 308.
}
\seealso{
}
\keyword{datasets}
\eof
\name{czech.dat}
\alias{czech.dat}
\docType{data}
\title{Czech auto workers data}
\description{
  Czech auto workers data
}
\usage{data(czech.dat)}
\format{
  A data frame with 64 observations on the following 7 variables.
  \describe{
    \item{y}{a numeric vector}
    \item{A}{a factor with levels \code{no} \code{yes}}
    \item{B}{a factor with levels \code{no} \code{yes}}
    \item{C}{a factor with levels \code{no} \code{yes}}
    \item{D}{a factor with levels \code{small} \code{large}}
    \item{E}{a factor with levels \code{small} \code{large}}
    \item{F}{a factor with levels \code{neg} \code{pos}}
  }
}
\source{
  Edwards and Havranek (1985)
}
\examples{
data(czech.dat)
}
\keyword{datasets}
\eof
\name{gof}
\alias{gof}
\title{Goodness-of-fit function for Poisson log-linear models}
\description{
  A goodness-of-fit function for Poisson log-linear models as required
  by \code{mcexact}.
}
\usage{
gof(y = NULL, mu = NULL, rowlabels = F)
}
\arguments{
  \item{y}{counts}
  \item{mu}{mean}
  \item{rowlabels}{labels of returned goodness-of-fit statistics}
}
\details{
  This function is a useful shell for writing alternative goodness-of-fit
  statistics for \code{mcexact}.
}
\value{
  If \code{rowlabels = TRUE}, then \code{gof} returns only the labels of the
  goodness of fit statistics. Otherwise it returns the actual values as
  a vector. 
}
\references{}
\author{Brian S. Caffo}
\note{}
\seealso{\code{\link{mcexact}}}

\examples{
#data(residence)
#get fitted values
#mu <- glm(residence$y ~ residence$x, family = poisson)$fit
#gof(residence$y, mu)
#gof(rowlabels = TRUE)
}
\keyword{htest}
\eof
\name{hyper}
\alias{hyper}
\title{Generalized hypergeometric distribution on the log scale}
\description{
  Returns the log hypergeometric conditional probability of a vector of Poisson
  counts up to an additive constant of proportionallity.
}
\usage{
hyper(y)
}
\arguments{
  \item{y}{Counts}
}
\details{
}
\value{
  A real-valued scalar.
}
\references{}
\author{Brian S. Caffo}
\note{}
\seealso{\code{\link{mcexact}}}

\examples{
}
\keyword{htest}
\eof
\name{mcexact}
\alias{mcexact}
\alias{build.mcx.obj}
\title{Computes Monte Carlo exact P-values for general log-linear models. }
\description{
  This function computes Monte Carlo estimates of conditional P-values
  for goodness of fit tests for general log-linear models.
}
\usage{
mcexact(formula,
        data,
        stat = gof,
        dens = hyper,
        nosim = 10 ^ 3,
        method = "bab",
        savechain = FALSE,
        tdf = 3,
        maxiter = nosim,
        p = NULL,
        batchsize = NULL)

build.mcx.obj(formula,
        data,
        stat = gof,
        dens = hyper,
        nosim = 10 ^ 3,
        method = "bab",
        savechain = FALSE,
        tdf = 3,
        maxiter = nosim,
        p = NULL,
        batchsize = NULL)
}
\arguments{
  \item{formula}{Null model formula specified as in \code{glm}}
  \item{data}{Data frame}
  \item{stat}{The test statistic, a function of the form \code{function(y, mu.hat)}
    where \code{y} is the observed and \code{mu.hat} are the fitted
    values. Current default \code{gof} is a bivariate function of the
    deviance and the Pearson chi-squared.}
  \item{dens}{The target density on the log scale up to a constant of
    proportionallity. A function of the form
    \code{function(y)}. Current default is (proportional to) the log of
    the generalized hypergeometric density.}
  \item{nosim}{Desired number of simulations.}
  \item{method}{Possibly two values, the importance sampling method of
    Booth and Butler, \code{method = "bab"} or the MCMC approach of
    Caffo and Booth \code{method = "cab"}.}
  \item{savechain}{If \code{TRUE} saves the values of the chain.}
  \item{tdf}{A tuning parameter}
  \item{maxiter}{For \code{method = "bab"} number of iterations is
    different from the number of simulations. \code{maxiter} is a
    bound on the total number of iterations.}
  \item{p}{A tuning parameter for \code{method = "cab"}.}
  \item{batchsize}{Required batchsizes for \code{method = "cab"}.}
}
\details{
}
\value{
  Returns a list of class either \code{"bab"} or \code{"cab"} depending
  on \code{method}. The list contains all of the inputs plus all
  required information to resume the simulation. Generic functions
  \code{print} and \code{summary} format the output while \code{update}
  can be used to resume simulations. \code{mcexact} is the front end while
  \code{build.mcx.obj} simply builds the basic object that \code{mcexact} applies to.
  \code{simulate.conditional} generates a matrix of simulated tables.
}
\references{
  Booth and Butler (1999), "An importance sampling algorithm for exact conditional tests in log-linear models", Biometrika 86: 321-332. 
  
  Caffo and Booth (2001). "A Markov Chain Monte Carlo Algorithm for Approximating Exact Conditional Probabilities", The Journal of Computational and Graphical Statistics 10: 730-45.

  http://www.biostat.jhsph.edu/~bcaffo/downloads.htm
}
\author{Brian Caffo }
\note{}

 
\seealso{\code{\link{fisher.test}}}

\examples{
#library(mcexact)
set.seed(1)

#importance sampling
data(residence.dat)
mcx <- mcexact(y ~ res.1985 + res.1980 + factor(sym.pair), data = residence.dat) 
summary(mcx)

#mcmc
data(pathologist.dat)
mcx <- mcexact(y ~ factor(A) + factor(B) + I(A * B),
               data = pathologist.dat,
               method = "cab",
               p = .5,
               nosim = 10 ^ 4,
               batchsize = 100)
summary(mcx)
}
\keyword{htest}
\eof
\name{mcexact.internals}
\alias{errorcheck}
\alias{rounded.tprob}
\title{Internal functions for mcexact}
\description{
  Internal functions used for mcexact.
}
\usage{
rounded.tprob(y, m, s, df)
errorcheck(y,
           x,
           stat,
           dens,
           nosim,
           method,
           savechain,
           tdf,
           maxiter,
           p,
           batchsize)
}
\arguments{
  \item{y}{counts}
  \item{m}{means}
  \item{s}{variances}
  \item{df}{degrees of freedom}
  \item{x}{model matrix}
  \item{stat}{function to be checked}
  \item{dens}{function to be checked}
  \item{nosim}{number of simulations to be checked}
  \item{method}{method to be checked}
  \item{savechain}{savechain flag to be checked}
  \item{tdf}{t degrees of freedom to be checked}
  \item{maxiter}{maximum number of iterations to be checked}
  \item{p}{prop of table entries left fixed to be checked}
  \item{batchsize}{batchsize to be checked}
}
\value{
  \code{rounded.tprob} returns rounded student's t probabilities for
  integers \code{y} with means \code{m} and variances
  \code{s}. \code{errorcheck} is a function containing most of the error
  checking that \code{mcexact} performs.
}
\details{
}
\references{
}
\seealso{\code{\link{mcexact}}}
\examples{
}
\author{Brian S. Caffo}
\keyword{htest}
\eof
\name{pathologist.dat}
\alias{pathologist.dat}
\title{Cross-classification of 118 tumor grades by two pathologists}
\description{
  Data frame of a 5x5 table of pathologists ratings of 118 tumors. Each
  pathologist, \code{A} and \code{B}, rated the tumors on a scale of 1
  to 5. \code{y} represents the counts of each combination of ratings.
}
\usage{
data(pathologist.dat)
}
\format{A list containing \code{y}-the counts and \code{x}-the design
  matrix for the uniform association model.
}
\references{Agresti (1990). \emph{Categorical Data
  Analysis}. Wiley-Interscience. Page 368.
}
\seealso{Page 263 of \emph{Categorical Data Analysis} for a description of the
  uniform assocation model.
}
\keyword{datasets}
\eof
\name{print.mcexact}
\alias{print.bab}
\alias{print.cab}
\alias{summary.bab}
\alias{summary.cab}
\title{Print utilities for mcexact}
\description{
  Generic print methods for objects of class \code{cab} and \code{bab}
  outputted from \code{mcexact}.
}
\usage{
\method{print}{bab}(x,...)
\method{summary}{bab}(object,...)
}
\arguments{
  \item{x}{An object of class \code{bab} or \code{cab}}
  \item{object}{An object of class \code{bab} or \code{cab}}
  \item{...}{Unused, retained for generic method consistency}
}
\value{
  \code{print.bab} and \code{print.cab} prints the P-value estimates
  obtained from \code{mcexact}. \code{summary.bab} and
  \code{summary.cab} prints extra information and returns a matrix
  of the P-value estimates.
}
\details{
}
\references{
}
\seealso{\code{\link{mcexact}}}
\examples{
#data(residence)
#resid.mcx <- mcexact(residence$y ~ residence$x, nosim = 10 ^ 2, maxiter = 10 ^ 4)
#resid.mcx #calls print.bab
#print(resid.mcx) #calls print.bab
#summary(resid.mcx) #calls summary.bab
}
\author{Brian S. Caffo}
\keyword{htest}
\eof
\name{residence.dat}
\alias{residence.dat}
\title{Residence in 1980 by residence in 1985.}
\description{
  A data frame of a 4x4 cross-classification of residences in 1980 by residence in
  1985. \code{residence$y} gives the counts, \code{res.1985} and
  \code{res.1980} give the 1980 and 1985 residences, \code{sym.pair} is
  used to fit the quasi-symmetry model.
}
\usage{data(residence.dat)
}
\format{A list containing \code{y}-the counts and \code{x}-the design
  matrix for the quasi-symmetry model.
}
\references{Agresti (1990). \emph{Categorical Data
  Analysis}. Wiley-Interscience. Page 357.
}
\seealso{Page 354 of \emph{Categorical Data Analysis} for a description of the
  quasi-symmetry model.
}
\keyword{datasets}
\eof
\name{simulate.conditional}
\alias{simulate.conditional}
\alias{simtable.bab}
\alias{simtable.cab}

\title{Simulates from the conditional distribution of a log-linear model}
\description{
  Simulates from the conditional distribution of log-linear models given
  the sufficient statistics. 
}
\usage{
simulate.conditional(formula,
                     data,
                     dens = hyper,
                     nosim = 10^3,
                     method = "bab",
                     tdf = 3,
                     maxiter = nosim,
                     p = NULL,
                     y.start = NULL)
simtable.bab(args, nosim = NULL, maxiter = NULL)
simtable.cab(args, nosim = NULL, p = NULL, y.start = NULL)
}
\arguments{
  \item{formula}{A formula for the log-linear model}
  \item{data}{A data frame}
  \item{dens}{The target density on the log scale up to a constant of
    proportionallity. A function of the form
    \code{function(y)}. Current default is (proportional to) the log of
    the generalized hypergeometric density.}
  \item{nosim}{Desired number of simulations.}
  \item{method}{Possibly two values, the importance sampling method of
    Booth and Butler, \code{method = "bab"} or the MCMC approach of
    Caffo and Booth \code{method = "cab"}.}
  \item{tdf}{A tuning parameter}
  \item{maxiter}{For \code{method = "bab"} number of iterations is
    different from the number of simulations. \code{maxiter} is a
    bound on the total number of iterations.}
  \item{p}{A tuning parameter for \code{method = "cab"}.}
  \item{y.start}{An optional starting value when \code{method = "cab"}}
  \item{args}{An object of class "bab" or "cab"}
}
\value{
  A matrix where each simulated table is a row.
}
\author{Brian Caffo}
\seealso{\code{\link{fisher.test}}}
\examples{
data(czech.dat)
chain2 <- simulate.conditional(y ~ (A + B + C + D + E + F) ^ 2,
                               data = czech.dat,
                               method = "cab",
                               nosim = 10 ^ 3,
                               p = .4,
                               dens = function(y) 0)
}
\keyword{htest}% at least one, from doc/KEYWORDS
\eof
\name{titanic.dat}
\alias{titanic.dat}
\docType{data}
\title{Titanic Survival Data}
\description{
  A data frame of counts of titanic passengers classified
  by class, age, sex and survival
}
\usage{data(titanic.dat)}
\format{
  A data frame with 32 observations on the following 5 variables.
  \describe{
    \item{y}{a numeric vector}
    \item{class}{a numeric vector}
    \item{age}{a numeric vector}
    \item{sex}{a numeric vector}
    \item{surv}{a numeric vector}
  }
}
\source{
  Cytel web site http://www.cytel.com
}
\examples{
data(titanic.dat)
}
\keyword{datasets}
\eof
\name{update.bab}
\alias{update.bab}
\alias{bab}
\title{Update method for objects of class bab}
\description{
  An update method for objects created by \code{mcexact} when
  \code{method = 'bab'}.
}
\usage{
\method{update}{bab}(object, ...)
bab(args, nosim = NULL, maxiter = NULL, savechain = FALSE)
}
\arguments{
  \item{object}{Output from \code{mcexact}}
  \item{\dots}{Alternative arguments for the update}
  \item{args}{Output from \code{mcexact}}
  \item{nosim}{The desired number of simulations to be performed in the
    update}
  \item{maxiter}{The maximum number of iterations allowed.}
  \item{savechain}{Saves the chain of goodness-of-fit statistics and
    their importance weights}
}
\details{
  The method \code{update.bab} calls the function \code{bab}, which is the
  engine for \code{mcexact} when \code{method = 'bab'}.
}
\value{
  A list of the form outputted from \code{mcexact}
}
\references{}
\author{Brian S. Caffo}
\note{}
\seealso{\code{\link{mcexact}}}

\examples{
data(residence.dat)
mcx <- mcexact(y ~ res.1985 + res.1980 + factor(sym.pair), data = residence.dat) 
summary(mcx)
mcx <- update(mcx, nosim = 10 ^ 4, maxiter = 10 ^ 6)
summary(mcx)
}
\keyword{htest}
\eof
\name{update.cab}
\alias{update.cab}
\alias{cab}
\title{Update method for objects of class cab}
\description{
  An update method for objects created by \code{mcexact} when
  \code{method = 'cab'}.
}
\usage{
\method{update}{cab}(object, ...)
cab(args,
    nosim = NULL,
    batchsize = NULL,
    savechain = FALSE,
    p = NULL,
    flush = FALSE)
}
\arguments{
  \item{object}{Output from \code{mcexact}}
  \item{\dots}{Alternative arguments for the update}
  \item{args}{Output from \code{mcexact}}
  \item{nosim}{The number of simulations to be performed in the update}
  \item{batchsize}{A new batchsize}
  \item{savechain}{Saves the chain of goodness-of-fit statistics}
  \item{p}{An updated proportion of simulated tables left fixed.}
  \item{flush}{Should the previous information be discarded?
    \code{flush} should be set to \code{true} if the batchsize is changed.}
}
\details{
  The method \code{update.cab} calls the function \code{cab}, which is the
  engine for \code{mcexact} when \code{method = 'cab'}.
}
\value{
  A list of the form outputted from \code{mcexact}
}
\references{}
\author{Brian S. Caffo}
\note{}
\seealso{\code{\link{mcexact}}}

\examples{
data(residence.dat)
mcx <- mcexact(y ~ res.1985 + res.1980 + factor(sym.pair),
               data = residence.dat,
               method = "cab",
               p = .5,
               batchsize = 100) 
summary(mcx)
mcx <- update(mcx, nosim = 10 ^ 4)
summary(mcx)
}
\keyword{htest}
\eof
